
============  ===============  ======  ========  =======  ===============  ======  =========================
name          value            unit    type      valid    default          code    description
============  ===============  ======  ========  =======  ===============  ======  =========================
description   UNKNOWN                  string    None     UNKNOWN          B       Description of this produ
                                                                                   ct
type          BaseProduct              string    None     BaseProduct      B       Product Type identificati
                                                                                   on. Name of class or CARD
                                                                                   .
creator       UNKNOWN                  string    None     UNKNOWN          B       Generator of this product
                                                                                   .
creationDate  1958-01-01               finetime  None     1958-01-01               Creation date of this pro
              00:00:00.000000                             00:00:00.000000          duct
              0                                           0
rootCause     UNKNOWN                  string    None     UNKNOWN          B       Reason of this run of pip
                                                                                   eline.
version       0.8                      string    None     0.8              B       Version of product
FORMATV       1.5.0.9                  string    None     1.5.0.9          B       Version of product schema
                                                                                    and revision
============  ===============  ======  ========  =======  ===============  ======  =========================
MetaData-listeners = ListnerSet{}